@@ -204,7 +204,7 @@ func (gui *Gui) getKey(key string) interface{} {
 
 // GetInitialKeybindings is a function.
 func (gui *Gui) GetInitialKeybindings() []*Binding {
-	config := gui.Config.GetUserConfig().Keybinding
+	config := gui.UserConfig.Keybinding
 
 	bindings := []*Binding{
 		{
@@ -743,14 +743,14 @@ func (gui *Gui) GetInitialKeybindings() []*Binding {
 			ViewName:    "commits",
 			Contexts:    []string{string(BRANCH_COMMITS_CONTEXT_KEY)},
 			Key:         gui.getKey(config.Commits.RenameCommit),
-			Handler:     gui.handleRenameCommit,
-			Description: gui.Tr.LcRenameCommit,
+			Handler:     gui.handleRewordCommit,
+			Description: gui.Tr.LcRewordCommit,
 		},
 		{
 			ViewName:    "commits",
 			Contexts:    []string{string(BRANCH_COMMITS_CONTEXT_KEY)},
 			Key:         gui.getKey(config.Commits.RenameCommitWithEditor),
-			Handler:     gui.handleRenameCommitEditor,
+			Handler:     gui.handleRewordCommitEditor,
 			Description: gui.Tr.LcRenameCommitEditor,
 		},
 		{
@@ -901,6 +901,13 @@ func (gui *Gui) GetInitialKeybindings() []*Binding {
 			Handler:     gui.handleCopySelectedCommitMessageToClipboard,
 			Description: gui.Tr.LcCopyCommitMessageToClipboard,
 		},
+		{
+			ViewName:    "commits",
+			Contexts:    []string{string(BRANCH_COMMITS_CONTEXT_KEY)},
+			Key:         gui.getKey(config.Commits.OpenInBrowser),
+			Handler:     gui.handleOpenCommitInBrowser,
+			Description: gui.Tr.LcOpenCommitInBrowser,
+		},
 		{
 			ViewName:    "commits",
 			Contexts:    []string{string(REFLOG_COMMITS_CONTEXT_KEY)},
@@ -1770,6 +1777,18 @@ func (gui *Gui) GetInitialKeybindings() []*Binding {
 			Handler:     gui.toggleWhitespaceInDiffView,
 			Description: gui.Tr.ToggleWhitespaceInDiffView,
 		},
+		{
+			ViewName:    "",
+			Key:         gui.getKey(config.Universal.IncreaseContextInDiffView),
+			Handler:     gui.IncreaseContextInDiffView,
+			Description: gui.Tr.IncreaseContextInDiffView,
+		},
+		{
+			ViewName:    "",
+			Key:         gui.getKey(config.Universal.DecreaseContextInDiffView),
+			Handler:     gui.DecreaseContextInDiffView,
+			Description: gui.Tr.DecreaseContextInDiffView,
+		},
 		{
 			ViewName: "extras",
 			Key:      gocui.MouseWheelUp,
