@@ -9,8 +9,7 @@ import (
 
 	"github.com/go-errors/errors"
 	"github.com/jesseduffield/gocui"
-	"github.com/jesseduffield/lazygit/pkg/commands"
-	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
+	"github.com/jesseduffield/lazygit/pkg/commands/types/enums"
 	"github.com/jesseduffield/lazygit/pkg/gui/mergeconflicts"
 )
 
@@ -65,7 +64,8 @@ func (gui *Gui) handlePopFileSnapshot() error {
 	if gitFile == nil {
 		return nil
 	}
-	gui.OnRunCommand(oscommands.NewCmdLogEntry("Undoing last conflict resolution", "Undo merge conflict resolution", false))
+	gui.logAction("Restoring file to previous state")
+	gui.logCommand("Undoing last conflict resolution", false)
 	if err := ioutil.WriteFile(gitFile.Name, []byte(prevContent), 0644); err != nil {
 		return err
 	}
@@ -90,6 +90,7 @@ func (gui *Gui) handlePickHunk() error {
 			if err := gui.handleCompleteMerge(); err != nil {
 				return err
 			}
+			return nil
 		}
 		return gui.refreshMergePanel()
 	})
@@ -142,7 +143,8 @@ func (gui *Gui) resolveConflict(selection mergeconflicts.Selection) (bool, error
 	case mergeconflicts.ALL:
 		logStr = "Picking all hunks"
 	}
-	gui.OnRunCommand(oscommands.NewCmdLogEntry(logStr, "Resolve merge conflict", false))
+	gui.logAction("Resolve merge conflict")
+	gui.logCommand(logStr, false)
 	return true, ioutil.WriteFile(gitFile.Name, []byte(output), 0644)
 }
 
@@ -150,11 +152,19 @@ func (gui *Gui) refreshMergePanelWithLock() error {
 	return gui.withMergeConflictLock(gui.refreshMergePanel)
 }
 
-func (gui *Gui) refreshMergePanel() error {
-	panelState := gui.State.Panels.Merging
+// not re-using state here because we can run into issues with mutexes when
+// doing that.
+func (gui *Gui) renderConflictsFromFilesPanel() error {
+	state := mergeconflicts.NewState()
+	_, err := gui.renderConflicts(state, false)
+
+	return err
+}
+
+func (gui *Gui) renderConflicts(state *mergeconflicts.State, hasFocus bool) (bool, error) {
 	cat, err := gui.catSelectedFile()
 	if err != nil {
-		return gui.refreshMainViews(refreshMainOpts{
+		return false, gui.refreshMainViews(refreshMainOpts{
 			main: &viewUpdateOpts{
 				title: "",
 				task:  NewRenderStringTask(err.Error()),
@@ -162,20 +172,24 @@ func (gui *Gui) refreshMergePanel() error {
 		})
 	}
 
-	panelState.SetConflictsFromCat(cat)
+	state.SetConflictsFromCat(cat)
 
-	if panelState.NoConflicts() {
-		return gui.handleCompleteMerge()
+	if state.NoConflicts() {
+		return false, gui.handleCompleteMerge()
 	}
 
-	hasFocus := gui.currentViewName() == "main"
-	content := mergeconflicts.ColoredConflictFile(cat, panelState.State, hasFocus)
+	content := mergeconflicts.ColoredConflictFile(cat, state, hasFocus)
 
-	if err := gui.scrollToConflict(); err != nil {
-		return err
+	if !gui.State.Panels.Merging.UserVerticalScrolling {
+		// TODO: find a way to not have to do this OnUIThread thing. Why doesn't it work
+		// without it given that we're calling the 'no scroll' variant below?
+		gui.OnUIThread(func() error {
+			gui.centerYPos(gui.Views.Main, state.GetConflictMiddle())
+			return nil
+		})
 	}
 
-	return gui.refreshMainViews(refreshMainOpts{
+	return true, gui.refreshMainViews(refreshMainOpts{
 		main: &viewUpdateOpts{
 			title:  gui.Tr.MergeConflictsTitle,
 			task:   NewRenderStringWithoutScrollTask(content),
@@ -184,6 +198,19 @@ func (gui *Gui) refreshMergePanel() error {
 	})
 }
 
+func (gui *Gui) refreshMergePanel() error {
+	conflictsFound, err := gui.renderConflicts(gui.State.Panels.Merging.State, true)
+	if err != nil {
+		return err
+	}
+
+	if !conflictsFound {
+		return gui.handleCompleteMerge()
+	}
+
+	return nil
+}
+
 func (gui *Gui) catSelectedFile() (string, error) {
 	item := gui.getSelectedFile()
 	if item == nil {
@@ -194,7 +221,7 @@ func (gui *Gui) catSelectedFile() (string, error) {
 		return "", errors.New(gui.Tr.NotAFile)
 	}
 
-	cat, err := gui.GitCommand.CatFile(item.Name)
+	cat, err := gui.Git.File.Cat(item.Name)
 	if err != nil {
 		gui.Log.Error(err)
 		return "", err
@@ -202,32 +229,15 @@ func (gui *Gui) catSelectedFile() (string, error) {
 	return cat, nil
 }
 
-func (gui *Gui) scrollToConflict() error {
-	if gui.State.Panels.Merging.UserVerticalScrolling {
-		return nil
-	}
-
-	panelState := gui.State.Panels.Merging
-	if panelState.NoConflicts() {
-		return nil
-	}
-
-	gui.centerYPos(gui.Views.Main, panelState.GetConflictMiddle())
-
-	return nil
-}
-
 func (gui *Gui) centerYPos(view *gocui.View, y int) {
 	ox, _ := view.Origin()
 	_, height := view.Size()
 	newOriginY := int(math.Max(0, float64(y-(height/2))))
-	gui.g.Update(func(g *gocui.Gui) error {
-		return view.SetOrigin(ox, newOriginY)
-	})
+	_ = view.SetOrigin(ox, newOriginY)
 }
 
 func (gui *Gui) getMergingOptions() map[string]string {
-	keybindingConfig := gui.Config.GetUserConfig().Keybinding
+	keybindingConfig := gui.UserConfig.Keybinding
 
 	return map[string]string{
 		fmt.Sprintf("%s %s", gui.getKeyDisplay(keybindingConfig.Universal.PrevItem), gui.getKeyDisplay(keybindingConfig.Universal.NextItem)):   gui.Tr.LcSelectHunk,
@@ -239,18 +249,11 @@ func (gui *Gui) getMergingOptions() map[string]string {
 }
 
 func (gui *Gui) handleEscapeMerge() error {
-	gui.takeOverMergeConflictScrolling()
-
-	gui.State.Panels.Merging.Reset()
 	if err := gui.refreshSidePanels(refreshOptions{scope: []RefreshableView{FILES}}); err != nil {
 		return err
 	}
-	// it's possible this method won't be called from the merging view so we need to
-	// ensure we only 'return' focus if we already have it
-	if gui.g.CurrentView() == gui.Views.Main {
-		return gui.pushContext(gui.State.Contexts.Files)
-	}
-	return nil
+
+	return gui.escapeMerge()
 }
 
 func (gui *Gui) handleCompleteMerge() error {
@@ -260,16 +263,26 @@ func (gui *Gui) handleCompleteMerge() error {
 	if err := gui.refreshSidePanels(refreshOptions{scope: []RefreshableView{FILES}}); err != nil {
 		return err
 	}
-	// if we got conflicts after unstashing, we don't want to call any git
-	// commands to continue rebasing/merging here
-	if gui.GitCommand.WorkingTreeState() == commands.REBASE_MODE_NORMAL {
-		return gui.handleEscapeMerge()
-	}
+
 	// if there are no more files with merge conflicts, we should ask whether the user wants to continue
-	if !gui.anyFilesWithMergeConflicts() {
+	if gui.Git.Status.WorkingTreeState() != enums.REBASE_MODE_NONE && !gui.anyFilesWithMergeConflicts() {
 		return gui.promptToContinueRebase()
 	}
-	return gui.handleEscapeMerge()
+
+	return gui.escapeMerge()
+}
+
+func (gui *Gui) escapeMerge() error {
+	gui.takeOverMergeConflictScrolling()
+
+	gui.State.Panels.Merging.Reset()
+
+	// it's possible this method won't be called from the merging view so we need to
+	// ensure we only 'return' focus if we already have it
+	if gui.g.CurrentView() == gui.Views.Main {
+		return gui.pushContext(gui.State.Contexts.Files)
+	}
+	return nil
 }
 
 // promptToContinueRebase asks the user if they want to continue the rebase/merge that's in progress
