@@ -58,7 +58,6 @@ type TranslationSet struct {
 	PullWait                            string
 	PushWait                            string
 	FetchWait                           string
-	FileNoMergeCons                     string
 	LcSoftReset                         string
 	AlreadyCheckedOutBranch             string
 	SureForceCheckout                   string
@@ -93,8 +92,7 @@ type TranslationSet struct {
 	Squash                              string
 	LcPickCommit                        string
 	LcRevertCommit                      string
-	OnlyRenameTopCommit                 string
-	LcRenameCommit                      string
+	LcRewordCommit                      string
 	LcDeleteCommit                      string
 	LcMoveDownCommit                    string
 	LcMoveUpCommit                      string
@@ -120,7 +118,6 @@ type TranslationSet struct {
 	SurePopStashEntry                   string
 	StashApply                          string
 	SureApplyStashEntry                 string
-	NoStashTo                           string
 	NoTrackedStagedFilesStash           string
 	StashChanges                        string
 	MergeAborted                        string
@@ -191,6 +188,7 @@ type TranslationSet struct {
 	ConfirmRebase                       string
 	ConfirmMerge                        string
 	FwdNoUpstream                       string
+	FwdNoLocalUpstream                  string
 	FwdCommitsToPush                    string
 	ErrorOccurred                       string
 	NoRoom                              string
@@ -284,6 +282,7 @@ type TranslationSet struct {
 	LcEnterFile                         string
 	ExitLineByLineMode                  string
 	EnterUpstream                       string
+	InvalidUpstream                     string
 	ReturnToRemotesList                 string
 	LcAddNewRemote                      string
 	LcNewRemoteName                     string
@@ -299,7 +298,11 @@ type TranslationSet struct {
 	SetUpstreamMessage                  string
 	LcEditRemote                        string
 	LcTagCommit                         string
+	TagMenuTitle                        string
 	TagNameTitle                        string
+	TagMessageTitle                     string
+	LcLightweightTag                    string
+	LcAnnotatedTag                      string
 	LcDeleteTag                         string
 	DeleteTagTitle                      string
 	DeleteTagPrompt                     string
@@ -427,12 +430,13 @@ type TranslationSet struct {
 	ToggleWhitespaceInDiffView          string
 	IgnoringWhitespaceInDiffView        string
 	ShowingWhitespaceInDiffView         string
+	IncreaseContextInDiffView           string
+	DecreaseContextInDiffView           string
 	CreatePullRequestOptions            string
 	LcCreatePullRequestOptions          string
 	LcDefaultBranch                     string
 	LcSelectBranch                      string
 	CreatePullRequest                   string
-	CreatingPullRequestAtUrl            string
 	SelectConfigFile                    string
 	NoConfigFileFoundErr                string
 	LcLoadingFileSuggestions            string
@@ -447,10 +451,12 @@ type TranslationSet struct {
 	ToggleShowGitGraphAll               string
 	ShowGitGraph                        string
 	SortCommits                         string
-	Spans                               Spans
+	CantChangeContextSizeError          string
+	LcOpenCommitInBrowser               string
+	Actions                             Actions
 }
 
-type Spans struct {
+type Actions struct {
 	CheckoutCommit                    string
 	CheckoutReflogCommit              string
 	CheckoutTag                       string
@@ -520,6 +526,7 @@ type Spans struct {
 	BulkDeinitialiseSubmodules        string
 	UpdateSubmodule                   string
 	CreateLightweightTag              string
+	CreateAnnotatedTag                string
 	DeleteTag                         string
 	PushTag                           string
 	NukeWorkingTree                   string
@@ -530,6 +537,10 @@ type Spans struct {
 	HardReset                         string
 	Undo                              string
 	Redo                              string
+	CopyPullRequestURL                string
+	OpenMergeTool                     string
+	OpenCommitInBrowser               string
+	OpenPullRequest                   string
 }
 
 const englishIntroPopupMessage = `
@@ -549,7 +560,8 @@ Thanks for using lazygit! Seriously you rock. Three things to share with you:
     Or even just star the repo to share the love!
 `
 
-func englishTranslationSet() TranslationSet {
+// exporting this so we can use it in tests
+func EnglishTranslationSet() TranslationSet {
 	return TranslationSet{
 		NotEnoughSpace:                      "Not enough space to render panels",
 		DiffTitle:                           "Diff",
@@ -597,17 +609,16 @@ func englishTranslationSet() TranslationSet {
 		PullWait:                            "Pulling...",
 		PushWait:                            "Pushing...",
 		FetchWait:                           "Fetching...",
-		FileNoMergeCons:                     "This file has no inline merge conflicts",
 		LcSoftReset:                         "soft reset",
 		AlreadyCheckedOutBranch:             "You have already checked out this branch",
 		SureForceCheckout:                   "Are you sure you want force checkout? You will lose all local changes",
 		ForceCheckoutBranch:                 "Force Checkout Branch",
 		BranchName:                          "Branch name",
-		NewBranchNameBranchOff:              "New Branch Name (Branch is off of {{.branchName}})",
+		NewBranchNameBranchOff:              "New Branch Name (Branch is off of '{{.branchName}}')",
 		CantDeleteCheckOutBranch:            "You cannot delete the checked out branch!",
 		DeleteBranch:                        "Delete Branch",
-		DeleteBranchMessage:                 "Are you sure you want to delete the branch {{.selectedBranchName}}?",
-		ForceDeleteBranchMessage:            "{{.selectedBranchName}} is not fully merged. Are you sure you want to delete it?",
+		DeleteBranchMessage:                 "Are you sure you want to delete the branch '{{.selectedBranchName}}'?",
+		ForceDeleteBranchMessage:            "'{{.selectedBranchName}}' is not fully merged. Are you sure you want to delete it?",
 		LcRebaseBranch:                      "rebase checked-out branch onto this branch",
 		CantRebaseOntoSelf:                  "You cannot rebase a branch onto itself",
 		CantMergeBranchIntoItself:           "You cannot merge a branch into itself",
@@ -633,14 +644,13 @@ func englishTranslationSet() TranslationSet {
 		Squash:                              "Squash",
 		LcPickCommit:                        "pick commit (when mid-rebase)",
 		LcRevertCommit:                      "revert commit",
-		OnlyRenameTopCommit:                 "Can only reword topmost commit from within lazygit. Use shift+R instead",
-		LcRenameCommit:                      "reword commit",
+		LcRewordCommit:                      "reword commit",
 		LcDeleteCommit:                      "delete commit",
 		LcMoveDownCommit:                    "move commit down one",
 		LcMoveUpCommit:                      "move commit up one",
 		LcEditCommit:                        "edit commit",
 		LcAmendToCommit:                     "amend commit with staged changes",
-		LcRenameCommitEditor:                "rename commit with editor",
+		LcRenameCommitEditor:                "reword commit with editor",
 		Error:                               "Error",
 		LcSelectHunk:                        "select hunk",
 		LcNavigateConflicts:                 "navigate conflicts",
@@ -659,7 +669,6 @@ func englishTranslationSet() TranslationSet {
 		SurePopStashEntry:                   "Are you sure you want to pop this stash entry?",
 		StashApply:                          "Stash apply",
 		SureApplyStashEntry:                 "Are you sure you want to apply this stash entry?",
-		NoStashTo:                           "No stash to {{.method}}",
 		NoTrackedStagedFilesStash:           "You have no tracked/staged files to stash",
 		StashChanges:                        "Stash changes",
 		MergeAborted:                        "Merge aborted",
@@ -728,9 +737,10 @@ func englishTranslationSet() TranslationSet {
 		GlobalTitle:                         "Global Keybindings",
 		ConflictsResolved:                   "all merge conflicts resolved. Continue?",
 		RebasingTitle:                       "Rebasing",
-		ConfirmRebase:                       "Are you sure you want to rebase {{.checkedOutBranch}} onto {{.selectedBranch}}?",
-		ConfirmMerge:                        "Are you sure you want to merge {{.selectedBranch}} into {{.checkedOutBranch}}?",
+		ConfirmRebase:                       "Are you sure you want to rebase '{{.checkedOutBranch}}' onto '{{.selectedBranch}}'?",
+		ConfirmMerge:                        "Are you sure you want to merge '{{.selectedBranch}}' into '{{.checkedOutBranch}}'?",
 		FwdNoUpstream:                       "Cannot fast-forward a branch with no upstream",
+		FwdNoLocalUpstream:                  "Cannot fast-forward a branch whose remote is not registered locally",
 		FwdCommitsToPush:                    "Cannot fast-forward a branch with commits to push",
 		ErrorOccurred:                       "An error occurred! Please create an issue at",
 		NoRoom:                              "Not enough room",
@@ -824,6 +834,7 @@ func englishTranslationSet() TranslationSet {
 		LcEnterFile:                         "enter file to add selected lines to the patch (or toggle directory collapsed)",
 		ExitLineByLineMode:                  `exit line-by-line mode`,
 		EnterUpstream:                       `Enter upstream as '<remote> <branchname>'`,
+		InvalidUpstream:                     "Invalid upstream. Must be in the format '<remote> <branchname>'",
 		ReturnToRemotesList:                 `Return to remotes list`,
 		LcAddNewRemote:                      `add new remote`,
 		LcNewRemoteName:                     `New remote name:`,
@@ -839,7 +850,11 @@ func englishTranslationSet() TranslationSet {
 		SetUpstreamMessage:                  "Are you sure you want to set the upstream branch of '{{.checkedOut}}' to '{{.selected}}'",
 		LcEditRemote:                        "edit remote",
 		LcTagCommit:                         "tag commit",
+		TagMenuTitle:                        "Create tag",
 		TagNameTitle:                        "Tag name:",
+		TagMessageTitle:                     "Tag message: ",
+		LcAnnotatedTag:                      "annotated tag",
+		LcLightweightTag:                    "lightweight tag",
 		LcDeleteTag:                         "delete tag",
 		DeleteTagTitle:                      "Delete tag",
 		DeleteTagPrompt:                     "Are you sure you want to delete tag '{{.tagName}}'?",
@@ -967,12 +982,13 @@ func englishTranslationSet() TranslationSet {
 		ToggleWhitespaceInDiffView:          "Toggle whether or not whitespace changes are shown in the diff view",
 		IgnoringWhitespaceInDiffView:        "Whitespace will be ignored in the diff view",
 		ShowingWhitespaceInDiffView:         "Whitespace will be shown in the diff view",
+		IncreaseContextInDiffView:           "Increase the size of the context shown around changes in the diff view",
+		DecreaseContextInDiffView:           "Decrease the size of the context shown around changes in the diff view",
 		CreatePullRequest:                   "Create pull request",
 		CreatePullRequestOptions:            "Create pull request options",
 		LcCreatePullRequestOptions:          "create pull request options",
 		LcDefaultBranch:                     "default branch",
 		LcSelectBranch:                      "select branch",
-		CreatingPullRequestAtUrl:            "Creating pull request at URL: %s",
 		SelectConfigFile:                    "Select config file",
 		NoConfigFileFoundErr:                "No config file found",
 		LcLoadingFileSuggestions:            "loading file suggestions",
@@ -987,7 +1003,9 @@ func englishTranslationSet() TranslationSet {
 		ToggleShowGitGraphAll:               "toggle show whole git graph (pass the `--all` flag to `git log`)",
 		ShowGitGraph:                        "show git graph",
 		SortCommits:                         "commit sort order",
-		Spans: Spans{
+		CantChangeContextSizeError:          "Cannot change context while in patch building mode because we were too lazy to support it when releasing the feature. If you really want it, please let us know!",
+		LcOpenCommitInBrowser:               "open commit in browser",
+		Actions: Actions{
 			// TODO: combine this with the original keybinding descriptions (those are all in lowercase atm)
 			CheckoutCommit:                    "Checkout commit",
 			CheckoutReflogCommit:              "Checkout reflog commit",
@@ -1012,6 +1030,7 @@ func englishTranslationSet() TranslationSet {
 			CreateFixupCommit:                 "Create fixup commit",
 			SquashAllAboveFixupCommits:        "Squash all above fixup commits",
 			CreateLightweightTag:              "Create lightweight tag",
+			CreateAnnotatedTag:                "Create annotated tag",
 			CopyCommitMessageToClipboard:      "Copy commit message to clipboard",
 			MoveCommitUp:                      "Move commit up",
 			MoveCommitDown:                    "Move commit down",
@@ -1068,6 +1087,10 @@ func englishTranslationSet() TranslationSet {
 			FastForwardBranch:                 "Fast forward branch",
 			Undo:                              "Undo",
 			Redo:                              "Redo",
+			CopyPullRequestURL:                "Copy pull request URL",
+			OpenMergeTool:                     "Open merge tool",
+			OpenCommitInBrowser:               "Open commit in browser",
+			OpenPullRequest:                   "Open pull request in browser",
 		},
 	}
 }
